@@ -205,23 +205,21 @@ class SupeRSS:
       return None
 
     # test for valid urls:
-    articles_urls = list(set([
+    article_urls = list(set([
       u for u in candidates if is_article_url(u)
       ]))
     
     # if we have one or more, update entry_urls and return the first
-    if len(articles_urls) >= 1:
-      return valid_urls[0]
+    if len(article_urls) >= 1:
+      return article_urls[0]
 
     # if we STILL haven't found anything, just
-    # return the first candidate:
-    return candidates[0]
-
+    # return the first candidate that looks like a url.
+    return [c for c in candidates if c.startswith('http')][0]
 
   def get_links(self, article_html):
     return [prepare_url(u) for u in urls_from_html(article_html)]
 
-
   def parse_entry(self, entry):
 
     """
